import path from 'path'
import fs from 'fs'
import os from 'os'
import { fileURLToPath } from 'url'
import decompress from 'decompress'
import decompressTargz from '@xhmikosr/decompress-targz'

const arch = process.env.BEEPER_CLIENT_SDK_TARGET_ARCH || os.arch()
const __dirname = path.dirname(fileURLToPath(import.meta.url))
const tarballName = `napi-v8-${process.platform}-${arch}.tar.gz`
const libPath = path.resolve(__dirname, '..', 'lib', 'napi-v8')
const tarballPath = path.join(libPath, tarballName)

async function removeAllTargz(directory) {
  const files = await fs.promises.readdir(directory);

  for (const file of files) {
    if (file.endsWith('tar.gz')) {
      const filePath = path.join(directory, file);
      await fs.promises.unlink(filePath);
    }
  }
}

console.log(`Extracting ${tarballName} to ${libPath}...`)

try {
  await decompress(tarballPath, libPath, {
    plugins: [decompressTargz()],
  })

  await removeAllTargz(libPath)
  console.log('Binary extracted successfully!')
} catch(err) {
  console.log('Error when extracting binary', err);
}
